This module hosts common functions that are used throughout Simmate. This includes things like grabbing the name of the active conda environment, creating a new directory, and compressing a folder to a zip file.

Typically, you don't need to interact with any of the functions in this module unless you are creating new functionality or contributing to our code.
